﻿param($installPath, $toolsPath, $package, $project)

$analyzersDir = Join-Path (Split-Path -Path $toolsPath -Parent) "analyzers"
if (-Not (Test-Path $analyzersDir))
{
    return
}

$analyzersPaths = Join-Path ( $analyzersDir ) * -Resolve

foreach($analyzersPath in $analyzersPaths)
{
    # Install the language agnostic analyzers.
    if (Test-Path $analyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $analyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
            }
        }
    }
}

# $project.Type gives the language name like (C# or VB.NET)
$languageFolder = ""
if($project.Type -eq "C#")
{
    $languageFolder = "cs"
}
if($project.Type -eq "VB.NET")
{
    $languageFolder = "vb"
}
if($languageFolder -eq "")
{
    return
}

foreach($analyzersPath in $analyzersPaths)
{
    # Install language specific analyzers.
    $languageAnalyzersPath = join-path $analyzersPath $languageFolder
    if (Test-Path $languageAnalyzersPath)
    {
        foreach ($analyzerFilePath in Get-ChildItem $languageAnalyzersPath -Filter *.dll)
        {
            if($project.Object.AnalyzerReferences)
            {
                $project.Object.AnalyzerReferences.Add($analyzerFilePath.FullName)
            }
        }
    }
}
# SIG # Begin signature block
# MIIpQQYJKoZIhvcNAQcCoIIpMjCCKS4CAQExDzANBglghkgBZQMEAgEFADB5Bgor
# BgEEAYI3AgEEoGswaTA0BgorBgEEAYI3AgEeMCYCAwEAAAQQH8w7YFlLCE63JNLG
# KX7zUQIBAAIBAAIBAAIBAAIBADAxMA0GCWCGSAFlAwQCAQUABCCh1voBODYpfCet
# zwmmor0XvG3ngI9/l8E/7NCzPBjyWaCCDfQwggZyMIIEWqADAgECAhMzAAAD0toZ
# Fl1tx0mvAAAAAAPSMA0GCSqGSIb3DQEBDAUAMH4xCzAJBgNVBAYTAlVTMRMwEQYD
# VQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNy
# b3NvZnQgQ29ycG9yYXRpb24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25p
# bmcgUENBIDIwMTEwHhcNMjQwMjIyMjAyNTUyWhcNMjUwMjE5MjAyNTUyWjBjMQsw
# CQYDVQQGEwJVUzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9u
# ZDEeMBwGA1UEChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMQ0wCwYDVQQDEwQuTkVU
# MIIBojANBgkqhkiG9w0BAQEFAAOCAY8AMIIBigKCAYEAt2oShTpbhBjAB7H8x0eR
# ZVb8oThSm3lULJc6gUqIYKR8jg/1UJ3TCIZDEP5YrrIv4SiP9HGkU7LhDi39ZuIl
# 7OhQsMpq+bFM1GnfPRmQl8ZHmSxgGgzQwi0h4B9urEy6hbrDSrkedwLEmLTH0wla
# 6EuJBkpUl2VjdCLHFr89WYFj09vM9qcGFO2Ex4fTdJxuJ4B4MlxMhtYjLFasiVrB
# kjCCSQrdtW4l762ps0g8qZFKZBYZ4MDOR5PMUR6ErZg/MeUGV67zKnVnRrvJ5w1a
# HfCXi7HIbrbpgFBDjbFwWGt4DmrZUESCXSeUXbgVrYlW8gMfxOXZG2vcAul59Z61
# geytB3f8lLTbDsZHYUqw/SJKWBJtpskJXoEguYbH9aW2ZMrEVnDme6ENo0WQGrhS
# oQExEBURVjysnb0WCpmNOzlgJMab5iSNJ5FyIz5BhqEBzpaFpdQJnSGVYLJZhJzu
# CDg1u8fTZ4c9R+CjdQBaTFAZGcvVAbYafpdLCO4Ua53rAgMBAAGjggGCMIIBfjAf
# BgNVHSUEGDAWBgorBgEEAYI3TAgBBggrBgEFBQcDAzAdBgNVHQ4EFgQUA1bGKvRd
# p3PIdhdkOpAJEMIo7z8wVAYDVR0RBE0wS6RJMEcxLTArBgNVBAsTJE1pY3Jvc29m
# dCBJcmVsYW5kIE9wZXJhdGlvbnMgTGltaXRlZDEWMBQGA1UEBRMNNDY0MjIzKzUw
# MjA4NTAfBgNVHSMEGDAWgBRIbmTlUAXTgqoXNzcitW2oynUClTBUBgNVHR8ETTBL
# MEmgR6BFhkNodHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpb3BzL2NybC9NaWND
# b2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3JsMGEGCCsGAQUFBwEBBFUwUzBRBggr
# BgEFBQcwAoZFaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraW9wcy9jZXJ0cy9N
# aWNDb2RTaWdQQ0EyMDExXzIwMTEtMDctMDguY3J0MAwGA1UdEwEB/wQCMAAwDQYJ
# KoZIhvcNAQEMBQADggIBAKUa9zGSKAiXDrTBYRMAHqD4gSxyp62CNIf2d0vg+j28
# KkazVXLOX0WxrRTd1S/uQLYOwFIAe9DMXeTSE53Ce8u6uTMJjBfxPbpNpw9SANPL
# whu40FP5yh/gCP2ae5eTeGRvH8G2Fr00aqscEH+vATPYWhvVa0Ky3hWwEWw+d+XQ
# FD7v0iS1hMHodV1nLWkGwhDX8bZxPc1DAx9tVX8vZK+T01Y+pj7Gx8b0uSptM3RU
# +Z7Xxe67mZ+O2A7sKBHQ62t6dI6JCNw8rx/UO6Sl10dH/S/M6iEWpO1sWzWAX/83
# cTgrQMUPe8AkBC3pldjIJKr6Pq6IRnZPCzopPV+CoP5GEbTiI1MZ4bQxwfaNelwO
# PyjmFO33vWlCrRB+fXKw8d0JxNo/unOW9cMediZV+B/wiyan6d9mWBx1QHXWTg9U
# NGSeJqnngd2h2LyftvCcpdrYWNsatmDtjLpzm5AdyobxZm2cxeDA9xkMQAqGo/IT
# uIy0mtRhW2WxCs/249xeL0TucAVxUma3WDnQys6a5d8BHrH1NE9zuumJVBADXlsQ
# E1EYDG8XDM+HymNFmNcnPtKP7wkPInVY4Z6PCRRV2CD9s+PP51fwpCajMrMX9V3o
# 2lr+/GEXhFIM5+F9uwltJph4yOU7tTWU57nWerifcE5YUk2dQUxkHgwWXfMlUeQr
# MIIHejCCBWKgAwIBAgIKYQ6Q0gAAAAAAAzANBgkqhkiG9w0BAQsFADCBiDELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEyMDAGA1UEAxMpTWljcm9z
# b2Z0IFJvb3QgQ2VydGlmaWNhdGUgQXV0aG9yaXR5IDIwMTEwHhcNMTEwNzA4MjA1
# OTA5WhcNMjYwNzA4MjEwOTA5WjB+MQswCQYDVQQGEwJVUzETMBEGA1UECBMKV2Fz
# aGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UEChMVTWljcm9zb2Z0IENv
# cnBvcmF0aW9uMSgwJgYDVQQDEx9NaWNyb3NvZnQgQ29kZSBTaWduaW5nIFBDQSAy
# MDExMIICIjANBgkqhkiG9w0BAQEFAAOCAg8AMIICCgKCAgEAq/D6chAcLq3YbqqC
# EE00uvK2WCGfQhsqa+laUKq4BjgaBEm6f8MMHt03a8YS2AvwOMKZBrDIOdUBFDFC
# 04kNeWSHfpRgJGyvnkmc6Whe0t+bU7IKLMOv2akrrnoJr9eWWcpgGgXpZnboMlIm
# Ei/nqwhQz7NEt13YxC4Ddato88tt8zpcoRb0RrrgOGSsbmQ1eKagYw8t00CT+OPe
# Bw3VXHmlSSnnDb6gE3e+lD3v++MrWhAfTVYoonpy4BI6t0le2O3tQ5GD2Xuye4Yb
# 2T6xjF3oiU+EGvKhL1nkkDstrjNYxbc+/jLTswM9sbKvkjh+0p2ALPVOVpEhNSXD
# OW5kf1O6nA+tGSOEy/S6A4aN91/w0FK/jJSHvMAhdCVfGCi2zCcoOCWYOUo2z3yx
# kq4cI6epZuxhH2rhKEmdX4jiJV3TIUs+UsS1Vz8kA/DRelsv1SPjcF0PUUZ3s/gA
# 4bysAoJf28AVs70b1FVL5zmhD+kjSbwYuER8ReTBw3J64HLnJN+/RpnF78IcV9uD
# jexNSTCnq47f7Fufr/zdsGbiwZeBe+3W7UvnSSmnEyimp31ngOaKYnhfsi+E11ec
# XL93KCjx7W3DKI8sj0A3T8HhhUSJxAlMxdSlQy90lfdu+HggWCwTXWCVmj5PM4Ta
# sIgX3p5O9JawvEagbJjS4NaIjAsCAwEAAaOCAe0wggHpMBAGCSsGAQQBgjcVAQQD
# AgEAMB0GA1UdDgQWBBRIbmTlUAXTgqoXNzcitW2oynUClTAZBgkrBgEEAYI3FAIE
# DB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB/zAfBgNV
# HSMEGDAWgBRyLToCMZBDuRQFTuHqp8cx0SOJNDBaBgNVHR8EUzBRME+gTaBLhklo
# dHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9NaWNSb29D
# ZXJBdXQyMDExXzIwMTFfMDNfMjIuY3JsMF4GCCsGAQUFBwEBBFIwUDBOBggrBgEF
# BQcwAoZCaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3BraS9jZXJ0cy9NaWNSb29D
# ZXJBdXQyMDExXzIwMTFfMDNfMjIuY3J0MIGfBgNVHSAEgZcwgZQwgZEGCSsGAQQB
# gjcuAzCBgzA/BggrBgEFBQcCARYzaHR0cDovL3d3dy5taWNyb3NvZnQuY29tL3Br
# aW9wcy9kb2NzL3ByaW1hcnljcHMuaHRtMEAGCCsGAQUFBwICMDQeMiAdAEwAZQBn
# AGEAbABfAHAAbwBsAGkAYwB5AF8AcwB0AGEAdABlAG0AZQBuAHQALiAdMA0GCSqG
# SIb3DQEBCwUAA4ICAQBn8oalmOBUeRou09h0ZyKbC5YR4WOSmUKWfdJ5DJDBZV8u
# LD74w3LRbYP+vj/oCso7v0epo/Np22O/IjWll11lhJB9i0ZQVdgMknzSGksc8zxC
# i1LQsP1r4z4HLimb5j0bpdS1HXeUOeLpZMlEPXh6I/MTfaaQdION9MsmAkYqwooQ
# u6SpBQyb7Wj6aC6VoCo/KmtYSWMfCWluWpiW5IP0wI/zRive/DvQvTXvbiWu5a8n
# 7dDd8w6vmSiXmE0OPQvyCInWH8MyGOLwxS3OW560STkKxgrCxq2u5bLZ2xWIUUVY
# ODJxJxp/sfQn+N4sOiBpmLJZiWhub6e3dMNABQamASooPoI/E01mC8CzTfXhj38c
# bxV9Rad25UAqZaPDXVJihsMdYzaXht/a8/jyFqGaJ+HNpZfQ7l1jQeNbB5yHPgZ3
# BtEGsXUfFL5hYbXw3MYbBL7fQccOKO7eZS/sl/ahXJbYANahRr1Z85elCUtIEJmA
# H9AAKcWxm6U/RXceNcbSoqKfenoi+kiVH6v7RyOA9Z74v2u3S5fi63V4GuzqN5l5
# GEv/1rMjaHXmr/r8i+sLgOppO6/8MO0ETI7f33VtY5E90Z1WTk+/gFcioXgRMiF6
# 70EKsT/7qMykXcGhiJtXcVZOSEXAQsmbdlsKgEhr/Xmfwb1tbWrJUnMTDXpQzTGC
# GqMwghqfAgEBMIGVMH4xCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9u
# MRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRp
# b24xKDAmBgNVBAMTH01pY3Jvc29mdCBDb2RlIFNpZ25pbmcgUENBIDIwMTECEzMA
# AAPS2hkWXW3HSa8AAAAAA9IwDQYJYIZIAWUDBAIBBQCgga4wGQYJKoZIhvcNAQkD
# MQwGCisGAQQBgjcCAQQwHAYKKwYBBAGCNwIBCzEOMAwGCisGAQQBgjcCARUwLwYJ
# KoZIhvcNAQkEMSIEILHG5OyijfDOM5bxiJFmyVasy7d752HLA4qfvHm7QzF9MEIG
# CisGAQQBgjcCAQwxNDAyoBSAEgBNAGkAYwByAG8AcwBvAGYAdKEagBhodHRwOi8v
# d3d3Lm1pY3Jvc29mdC5jb20wDQYJKoZIhvcNAQEBBQAEggGAM4jKVPH5hoCi+uxs
# 2N89c0zPiDr/oSfASA3XmQLzMo9kej7J9YpD2al4Dha4CsDfvQxFna3bhoYfDjVA
# YO2gGpgi3eqKNYgMkfd9fXZLH3fudSK8ab4WQt0VdnDQqF0p6uFC10t5Nsl5F0dz
# eX8HLNV21QfjAnnxOuRge/bmcUMbQpA+xLTuQq7Kap3J3gJMndv91BOufBlV31Ck
# YT6R7c6Jk6REv1V2fi/t2WZ3DvKsHFQjv2tcdbOrpwjiLmsQDWyVdYxGnLpJvf38
# I5Qe8SOZw1WxhfydFoK1PqQLJ0Aj5Q4qIXkUXvuxIMoV35opZ8XlHNCEjoZ7TVEb
# 0LcCE9ZTs/C/PdCPtBbxSKEFdSbUWvYNJRsbeVBg2/qzJ4xRtnSymqsriBfQ50gy
# APOUvuRoF1GvVp1e+nLrZBr35LfwCCy1PrjrkcJRf6Y0rhISdsh3FaPB/uykk1gt
# HiTUqEM/5u2zg7o1sv9QkxRtkWRLJuBVnR/qxP0eyiOmnKcroYIXrTCCF6kGCisG
# AQQBgjcDAwExgheZMIIXlQYJKoZIhvcNAQcCoIIXhjCCF4ICAQMxDzANBglghkgB
# ZQMEAgEFADCCAVoGCyqGSIb3DQEJEAEEoIIBSQSCAUUwggFBAgEBBgorBgEEAYRZ
# CgMBMDEwDQYJYIZIAWUDBAIBBQAEIJ1kYRcwK+eSz/cDj8h7DjMbzxrekEZuke5o
# LDgZFd9FAgZmvgJR+KYYEzIwMjQwODE1MTk0MDMyLjg1NlowBIACAfSggdmkgdYw
# gdMxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
# ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xLTArBgNVBAsT
# JE1pY3Jvc29mdCBJcmVsYW5kIE9wZXJhdGlvbnMgTGltaXRlZDEnMCUGA1UECxMe
# blNoaWVsZCBUU1MgRVNOOjU5MUEtMDVFMC1EOTQ3MSUwIwYDVQQDExxNaWNyb3Nv
# ZnQgVGltZS1TdGFtcCBTZXJ2aWNloIIR+zCCBygwggUQoAMCAQICEzMAAAH0F0aF
# wMs/OeUAAQAAAfQwDQYJKoZIhvcNAQELBQAwfDELMAkGA1UEBhMCVVMxEzARBgNV
# BAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jv
# c29mdCBDb3Jwb3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAg
# UENBIDIwMTAwHhcNMjQwNzI1MTgzMDU5WhcNMjUxMDIyMTgzMDU5WjCB0zELMAkG
# A1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24xEDAOBgNVBAcTB1JlZG1vbmQx
# HjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlvbjEtMCsGA1UECxMkTWljcm9z
# b2Z0IElyZWxhbmQgT3BlcmF0aW9ucyBMaW1pdGVkMScwJQYDVQQLEx5uU2hpZWxk
# IFRTUyBFU046NTkxQS0wNUUwLUQ5NDcxJTAjBgNVBAMTHE1pY3Jvc29mdCBUaW1l
# LVN0YW1wIFNlcnZpY2UwggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQCn
# CE4TptCAL2qriMkZfYDXKg5t+TSp61DySSP7mbftYHEOWxnmgmeN/Meymo+I4RXN
# nbLbKAaA1nf/F1lA3t/0DVanUB2HmoddlmHdIFfwAG5zr1NvdwnkoJlxcOy5/CZd
# 4KPzUTMkQhmq5V1XxJOVC54H9vUwhi3lEqKze7DN2V9KXRyQdsbOg73VhMqDogTG
# opiiMat4KimcgrE6+SvlVmyPZ/3kFvUsYS+6EEib8LsnKy8m8FlY22uynPJdWe6j
# 6QMTJnCmSmGxHxm92L6z+lCKh+Z1tbVSrNaWpdBWChhdtpiQTJpKH+F4G3CPW257
# 4ty45wcA+BvBm9AuSwporjqiS2t6A5Hh7SJywaIBZH0gv6fLiaUJQ0DzgXsYQRY4
# S+JuKDvCytNrplvO4yzJOLYDPio9XdBGQWDFJunhHg4QqeKfwnPhcsjXBeEGEikw
# Z8DcFPznSepqbNKIPkvmnH5W18KLQwlNLYsMXU9pVnCXJVkhWNUcryiHYdgb1Pbo
# WNH38jzmLkTHGaEenEzZn5SEl5kDovPjnab/7GsDjGt1hqzlybsVSHLbis8tUf4X
# L5nLAcCn1z2hZOu2N8gqosi9i2AlzjVDxbFtk9HsHW5+3wEWy/PZ05IuTE8Mtxdb
# LXoA3Lve/SKkLEDBQQL2GyyLQt0HxOGI1//gD5FnywIDAQABo4IBSTCCAUUwHQYD
# VR0OBBYEFCt0ZaEK0Sw+J3UsnOxNotMpBt+bMB8GA1UdIwQYMBaAFJ+nFV0AXmJd
# g/Tl0mWnG1M1GelyMF8GA1UdHwRYMFYwVKBSoFCGTmh0dHA6Ly93d3cubWljcm9z
# b2Z0LmNvbS9wa2lvcHMvY3JsL01pY3Jvc29mdCUyMFRpbWUtU3RhbXAlMjBQQ0El
# MjAyMDEwKDEpLmNybDBsBggrBgEFBQcBAQRgMF4wXAYIKwYBBQUHMAKGUGh0dHA6
# Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMvY2VydHMvTWljcm9zb2Z0JTIwVGlt
# ZS1TdGFtcCUyMFBDQSUyMDIwMTAoMSkuY3J0MAwGA1UdEwEB/wQCMAAwFgYDVR0l
# AQH/BAwwCgYIKwYBBQUHAwgwDgYDVR0PAQH/BAQDAgeAMA0GCSqGSIb3DQEBCwUA
# A4ICAQDdwdIPEkpQOyBpwh9FfrS6A4NKGwGrC0RRFRtRd4OZhhJrmgWPfhG6NbeA
# 54K385sM7jm9+mdgbk5LlijDCwXDX2CIIjolX5xwb+qozTyfEBJvPBa2q2ivNCIm
# H26mwThNVl4pheZvLHtY3211tUisJ6VWPs/qJ8wdNIu3oGbKhLbGULZx+Ao88DXe
# 9Ld66pSXrPB7sYCGN+M1eMqUThI1Ym92qCu/QZREqOqZqY2+GZIlqd7pNjOl0MJ6
# Crxp2UYfzkjURYqZ8RFvWXMrLk4w7Z70iQCW/J2lS6fQLew0S2nR6GWJPRKtqryN
# xhUMfgDYL8xssEjCKSPCIUZDhKUUtPZOBvga++lxZXMHHAOj0hEHCnOeBvLNuGH3
# lRU6tAvattYescNITd2B0vbK5odGBjsdhguzku2zfTBT066Hw3nhFS1roYVkXHkD
# i4hODIlxV1ZVo3SqOzR4SPATI1S/RxEu4dYkF6OQx7epECG8KOeGujsMZFZoiV3J
# /NmqWfoWyctDduX5m9UlZNgm4v4hksjZKLcishF+Nxyfb1fYFf+/PYpxi5siMrpd
# 9i+tlA3hcpue9KoE0DAg9jbEl4Hij08MQUjatw9otTLPkhXsk/clGmCDfGxSq8Ue
# VIbq4whaPAfQZAgjCsLbNHL6U1mw4qeu7LIcxBM/uPLlT3aoQTCCB3EwggVZoAMC
# AQICEzMAAAAVxedrngKbSZkAAAAAABUwDQYJKoZIhvcNAQELBQAwgYgxCzAJBgNV
# BAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4w
# HAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xMjAwBgNVBAMTKU1pY3Jvc29m
# dCBSb290IENlcnRpZmljYXRlIEF1dGhvcml0eSAyMDEwMB4XDTIxMDkzMDE4MjIy
# NVoXDTMwMDkzMDE4MzIyNVowfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hp
# bmd0b24xEDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jw
# b3JhdGlvbjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTAw
# ggIiMA0GCSqGSIb3DQEBAQUAA4ICDwAwggIKAoICAQDk4aZM57RyIQt5osvXJHm9
# DtWC0/3unAcH0qlsTnXIyjVX9gF/bErg4r25PhdgM/9cT8dm95VTcVrifkpa/rg2
# Z4VGIwy1jRPPdzLAEBjoYH1qUoNEt6aORmsHFPPFdvWGUNzBRMhxXFExN6AKOG6N
# 7dcP2CZTfDlhAnrEqv1yaa8dq6z2Nr41JmTamDu6GnszrYBbfowQHJ1S/rboYiXc
# ag/PXfT+jlPP1uyFVk3v3byNpOORj7I5LFGc6XBpDco2LXCOMcg1KL3jtIckw+DJ
# j361VI/c+gVVmG1oO5pGve2krnopN6zL64NF50ZuyjLVwIYwXE8s4mKyzbnijYjk
# lqwBSru+cakXW2dg3viSkR4dPf0gz3N9QZpGdc3EXzTdEonW/aUgfX782Z5F37Zy
# L9t9X4C626p+Nuw2TPYrbqgSUei/BQOj0XOmTTd0lBw0gg/wEPK3Rxjtp+iZfD9M
# 269ewvPV2HM9Q07BMzlMjgK8QmguEOqEUUbi0b1qGFphAXPKZ6Je1yh2AuIzGHLX
# pyDwwvoSCtdjbwzJNmSLW6CmgyFdXzB0kZSU2LlQ+QuJYfM2BjUYhEfb3BvR/bLU
# HMVr9lxSUV0S2yW6r1AFemzFER1y7435UsSFF5PAPBXbGjfHCBUYP3irRbb1Hode
# 2o+eFnJpxq57t7c+auIurQIDAQABo4IB3TCCAdkwEgYJKwYBBAGCNxUBBAUCAwEA
# ATAjBgkrBgEEAYI3FQIEFgQUKqdS/mTEmr6CkTxGNSnPEP8vBO4wHQYDVR0OBBYE
# FJ+nFV0AXmJdg/Tl0mWnG1M1GelyMFwGA1UdIARVMFMwUQYMKwYBBAGCN0yDfQEB
# MEEwPwYIKwYBBQUHAgEWM2h0dHA6Ly93d3cubWljcm9zb2Z0LmNvbS9wa2lvcHMv
# RG9jcy9SZXBvc2l0b3J5Lmh0bTATBgNVHSUEDDAKBggrBgEFBQcDCDAZBgkrBgEE
# AYI3FAIEDB4KAFMAdQBiAEMAQTALBgNVHQ8EBAMCAYYwDwYDVR0TAQH/BAUwAwEB
# /zAfBgNVHSMEGDAWgBTV9lbLj+iiXGJo0T2UkFvXzpoYxDBWBgNVHR8ETzBNMEug
# SaBHhkVodHRwOi8vY3JsLm1pY3Jvc29mdC5jb20vcGtpL2NybC9wcm9kdWN0cy9N
# aWNSb29DZXJBdXRfMjAxMC0wNi0yMy5jcmwwWgYIKwYBBQUHAQEETjBMMEoGCCsG
# AQUFBzAChj5odHRwOi8vd3d3Lm1pY3Jvc29mdC5jb20vcGtpL2NlcnRzL01pY1Jv
# b0NlckF1dF8yMDEwLTA2LTIzLmNydDANBgkqhkiG9w0BAQsFAAOCAgEAnVV9/Cqt
# 4SwfZwExJFvhnnJL/Klv6lwUtj5OR2R4sQaTlz0xM7U518JxNj/aZGx80HU5bbsP
# MeTCj/ts0aGUGCLu6WZnOlNN3Zi6th542DYunKmCVgADsAW+iehp4LoJ7nvfam++
# Kctu2D9IdQHZGN5tggz1bSNU5HhTdSRXud2f8449xvNo32X2pFaq95W2KFUn0CS9
# QKC/GbYSEhFdPSfgQJY4rPf5KYnDvBewVIVCs/wMnosZiefwC2qBwoEZQhlSdYo2
# wh3DYXMuLGt7bj8sCXgU6ZGyqVvfSaN0DLzskYDSPeZKPmY7T7uG+jIa2Zb0j/aR
# AfbOxnT99kxybxCrdTDFNLB62FD+CljdQDzHVG2dY3RILLFORy3BFARxv2T5JL5z
# bcqOCb2zAVdJVGTZc9d/HltEAY5aGZFrDZ+kKNxnGSgkujhLmm77IVRrakURR6nx
# t67I6IleT53S0Ex2tVdUCbFpAUR+fKFhbHP+CrvsQWY9af3LwUFJfn6Tvsv4O+S3
# Fb+0zj6lMVGEvL8CwYKiexcdFYmNcP7ntdAoGokLjzbaukz5m/8K6TT4JDVnK+AN
# uOaMmdbhIurwJ0I9JZTmdHRbatGePu1+oDEzfbzL6Xu/OHBE0ZDxyKs6ijoIYn/Z
# cGNTTY3ugm2lBRDBcQZqELQdVTNYs6FwZvKhggNWMIICPgIBATCCAQGhgdmkgdYw
# gdMxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNoaW5ndG9uMRAwDgYDVQQHEwdS
# ZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29ycG9yYXRpb24xLTArBgNVBAsT
# JE1pY3Jvc29mdCBJcmVsYW5kIE9wZXJhdGlvbnMgTGltaXRlZDEnMCUGA1UECxMe
# blNoaWVsZCBUU1MgRVNOOjU5MUEtMDVFMC1EOTQ3MSUwIwYDVQQDExxNaWNyb3Nv
# ZnQgVGltZS1TdGFtcCBTZXJ2aWNloiMKAQEwBwYFKw4DAhoDFQC/4tn9WDSzXtd6
# TiIb1H1z/v4AjqCBgzCBgKR+MHwxCzAJBgNVBAYTAlVTMRMwEQYDVQQIEwpXYXNo
# aW5ndG9uMRAwDgYDVQQHEwdSZWRtb25kMR4wHAYDVQQKExVNaWNyb3NvZnQgQ29y
# cG9yYXRpb24xJjAkBgNVBAMTHU1pY3Jvc29mdCBUaW1lLVN0YW1wIFBDQSAyMDEw
# MA0GCSqGSIb3DQEBCwUAAgUA6miA0DAiGA8yMDI0MDgxNTEzMjc0NFoYDzIwMjQw
# ODE2MTMyNzQ0WjB0MDoGCisGAQQBhFkKBAExLDAqMAoCBQDqaIDQAgEAMAcCAQAC
# AgCxMAcCAQACAhNUMAoCBQDqadJQAgEAMDYGCisGAQQBhFkKBAIxKDAmMAwGCisG
# AQQBhFkKAwKgCjAIAgEAAgMHoSChCjAIAgEAAgMBhqAwDQYJKoZIhvcNAQELBQAD
# ggEBALfraQK5uTnyU/ih/gtOym3nZakdKNOuPqZEkGucMEpQP2mAKcX/9Sx2mMGg
# AwF0kxPqPxEH/JnR2gT0n91Nxo0r/lFJ5njBDkhc0uTnvUBYe6cSno2RW2LDzPv6
# p6EG9+T6/AgKRL2zM3cwjRmuX/fX9yEbvL11p33ihWUL05zsLuk95jVxkde8VNHT
# P+L1ZxRzYmp+giLPdmr+rcmDlWz4XcMb5rl+PMPLah6/UWwuuha2/44gJ1eE9iqQ
# fFYoF9OE5SIeht/4aBQNB2AIYpCaGV/EZLePhqkT9BeA4UMW7AoaYq1JJXMg6VbB
# 7Syl2RNkiUpD4JYb/T3EtK6+ZJQxggQNMIIECQIBATCBkzB8MQswCQYDVQQGEwJV
# UzETMBEGA1UECBMKV2FzaGluZ3RvbjEQMA4GA1UEBxMHUmVkbW9uZDEeMBwGA1UE
# ChMVTWljcm9zb2Z0IENvcnBvcmF0aW9uMSYwJAYDVQQDEx1NaWNyb3NvZnQgVGlt
# ZS1TdGFtcCBQQ0EgMjAxMAITMwAAAfQXRoXAyz855QABAAAB9DANBglghkgBZQME
# AgEFAKCCAUowGgYJKoZIhvcNAQkDMQ0GCyqGSIb3DQEJEAEEMC8GCSqGSIb3DQEJ
# BDEiBCB8eZ57UeKH8Lq/aLJ5WBOp2zeHNWVCu2zqCeETxOyQuDCB+gYLKoZIhvcN
# AQkQAi8xgeowgecwgeQwgb0EID9YwnxuJpPqeO+SScHxDuFJAiLzKzq8gG9mDrRE
# GNZrMIGYMIGApH4wfDELMAkGA1UEBhMCVVMxEzARBgNVBAgTCldhc2hpbmd0b24x
# EDAOBgNVBAcTB1JlZG1vbmQxHjAcBgNVBAoTFU1pY3Jvc29mdCBDb3Jwb3JhdGlv
# bjEmMCQGA1UEAxMdTWljcm9zb2Z0IFRpbWUtU3RhbXAgUENBIDIwMTACEzMAAAH0
# F0aFwMs/OeUAAQAAAfQwIgQgSiADTrROwfr4gYCX5O9BMiPafgTXjLqFtAwXJnAu
# i74wDQYJKoZIhvcNAQELBQAEggIAV86IELC0BdbCwOVpYpCQTdWq0B9teTNpXBcM
# mO9NyqDC2QZXrLNA6CUXRDJ4tIl7dou3qug9iidvfX3hZ5KwnaApUcyueHWkrUBj
# cWqinamT4LBCb7bPI9A892UHcu8T0DOIyfbWKLUe0oyJ0AWZANxPMUyfsXiGpAYJ
# jVFi2nRAvnd7IKoyYvznVeml8GooSCu5wZWqP/MENZN/yth800BCX85QWA4LRQVC
# uH5pwIDiQRVayJalUXrokajzcRo8UN/01EwRnVettJGpl4gwkB3K26OjtDsmzgGz
# vOEsW7oRzWMFwSSQpNm/De0YbRq9uCtIu8QeruCCzV1ChZkr60+ZmNc06xBQ2fzx
# HpZl2cdLQrsxL1LQhIaxYWZR8m/nZVBXvgU/1BjFHUUZEgdDsLPnmVoZy+H/C1+R
# dRNfD76tXa9el8OAvgHVD5bg3/7w9zZT61ttDF+yhFc1NO9CRC6aRMt7qEZI8o7i
# DpXxcynxpMjigXFdh4qukicp8Q4jDdgwZj46q9MRLm3N1ciaLrP6au+wL4jqSQAi
# WFWDro5RknWpIl/SixFZzBj1D1v3/lKPckZE4OePuhO14dbRuuzepCdTN7yQjyLc
# INBA7ebFdT7nSX/oKRFGYaNne4c+crCuiSVk5P5uij6GTFOxnnuHBtiv3vXyP7RU
# LCif95k=
# SIG # End signature block
